"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.autopay_schedule import (
    AutopaySchedule,
)
from mindbodypublicapi.models.contract_item import (
    ContractItem,
)
from mindbodypublicapi.models.membership_type_restriction import (
    MembershipTypeRestriction,
)


class Contract(object):
    """Implementation of the 'Contract' model.

    Attributes:
        id (int): The contract’s ID at the subscriber’s business.
        name (str): The name of the contract.
        description (str): A description of the contract.
        assigns_membership_id (int): The ID of the membership that was assigned to
            the client when the client signed up for a contract.
        assigns_membership_name (str): The name of the membership that was assigned
            to the client when the client signed up for this contract.
        sold_online (bool): When `true`, indicates that this membership is intended
            to be shown to clients in client experiences.<br />  When `false`, this
            contract should only be shown to staff members.
        contract_items (List[ContractItem]): Contains information about the items in
            the contract.
        intro_offer (str): Defines whether this contract is treated as an
            introductory offer. If this is an introductory offer, then clients are
            always charged a set number of times rather than month to month, using
            their AutoPays. Possible values are:  * None  * NewConsumer  *
            NewAndReturningConsumer
        autopay_schedule (AutopaySchedule): The model property of type
            AutopaySchedule.
        number_of_autopays (int): The number of times that the AutoPay is to be run.
            This value is null if `FrequencyType` is `MonthToMonth`.
        autopay_trigger_type (str): Defines whether the AutoPay, if applicable to
            this contract, runs on a set schedule or when the pricing option runs out
            or expires. Possible values are:  * OnSetSchedule  *
            PricingOptionRunsOutOrExpires
        action_upon_completion_of_autopays (str): The renewal action to be taken when
            this AutoPay is completed. Possible values are:  * ContractExpires  *
            ContractAutomaticallyRenews
        clients_charged_on (str): The value that indicates when clients are charged.
            Possible values are:  * OnSaleDate  * FirstOfTheMonth  *
            FifteenthOfTheMonth  * LastDayOfTheMonth  * FirstOrFifteenthOfTheMonth  *
            FirstOrSixteenthOfTheMonth  * FifteenthOrEndOfTheMonth  * SpecificDate
        clients_charged_on_specific_date (datetime): If `ClientsChargedOn` is defined
            as a specific date, this property holds the value of that date.
            Otherwise, this property is null.
        discount_amount (float): The calculated discount applied to the items in this
            contract.
        deposit_amount (float): The amount of the deposit required for this contract.
        first_autopay_free (bool): When `true`, indicates that the first payment for
            the AutoPay is free.
        last_autopay_free (bool): When `true`, indicates that the last payment for
            the AutoPay is free.
        client_terminate_online (bool): When `true`, indicates that the client can
            terminate this contract on the Internet.
        membership_type_restrictions (List[MembershipTypeRestriction]): Contains
            information about the memberships that can purchase this contract. If
            null, then no membership restrictions exist, and anyone can purchase the
            contract.
        location_purchase_restriction_ids (List[int]): The IDs of the locations where
            this contract may be sold. If there are no restrictions, this value is
            null.
        location_purchase_restriction_names (List[str]): Location names where the
            contract may be purchased. If this value is null, there are no
            restrictions.
        agreement_terms (str): Business-defined terms and conditions for the contract.
        requires_electronic_confirmation (bool): When `true`, clients who purchase
            the contract are prompted to agree to the terms of the contract the next
            time that they log in.
        autopay_enabled (bool): When `true`, this contract establishes an AutoPay on
            the client’s account.
        first_payment_amount_subtotal (float): The subtotal of the amount that the
            client is to be charged when signing up for the contract.
        first_payment_amount_tax (float): The amount of tax that the client is to be
            charged when signing up for the contract.
        first_payment_amount_total (float): The total amount that the client is to be
            charged when signing up for the contract.
        recurring_payment_amount_subtotal (float): The subtotal amount that the
            client is to be charged on an ongoing basis.
        recurring_payment_amount_tax (float): The amount of tax the client is to be
            charged on an ongoing basis.
        recurring_payment_amount_total (float): The total amount that the client is
            to be charged on an ongoing basis.
        total_contract_amount_subtotal (float): The subtotal amount that the client
            is to be charged over the lifespan of the contract.
        total_contract_amount_tax (float): The total amount of tax the client is to
            be charged over the lifespan of the contract.
        total_contract_amount_total (float): The total amount the client is to be
            charged over the lifespan of the contract.
        promo_payment_amount_subtotal (float): Subtotal promotional period
        promo_payment_amount_tax (float): Taxes of promotional period
        promo_payment_amount_total (float): Total of promotional period
        number_of_promo_autopays (int): Number of times that the AutoPay runs under
            the promotional period

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "assigns_membership_id": "AssignsMembershipId",
        "assigns_membership_name": "AssignsMembershipName",
        "sold_online": "SoldOnline",
        "contract_items": "ContractItems",
        "intro_offer": "IntroOffer",
        "autopay_schedule": "AutopaySchedule",
        "number_of_autopays": "NumberOfAutopays",
        "autopay_trigger_type": "AutopayTriggerType",
        "action_upon_completion_of_autopays": "ActionUponCompletionOfAutopays",
        "clients_charged_on": "ClientsChargedOn",
        "clients_charged_on_specific_date": "ClientsChargedOnSpecificDate",
        "discount_amount": "DiscountAmount",
        "deposit_amount": "DepositAmount",
        "first_autopay_free": "FirstAutopayFree",
        "last_autopay_free": "LastAutopayFree",
        "client_terminate_online": "ClientTerminateOnline",
        "membership_type_restrictions": "MembershipTypeRestrictions",
        "location_purchase_restriction_ids": "LocationPurchaseRestrictionIds",
        "location_purchase_restriction_names": "LocationPurchaseRestrictionNames",
        "agreement_terms": "AgreementTerms",
        "requires_electronic_confirmation": "RequiresElectronicConfirmation",
        "autopay_enabled": "AutopayEnabled",
        "first_payment_amount_subtotal": "FirstPaymentAmountSubtotal",
        "first_payment_amount_tax": "FirstPaymentAmountTax",
        "first_payment_amount_total": "FirstPaymentAmountTotal",
        "recurring_payment_amount_subtotal": "RecurringPaymentAmountSubtotal",
        "recurring_payment_amount_tax": "RecurringPaymentAmountTax",
        "recurring_payment_amount_total": "RecurringPaymentAmountTotal",
        "total_contract_amount_subtotal": "TotalContractAmountSubtotal",
        "total_contract_amount_tax": "TotalContractAmountTax",
        "total_contract_amount_total": "TotalContractAmountTotal",
        "promo_payment_amount_subtotal": "PromoPaymentAmountSubtotal",
        "promo_payment_amount_tax": "PromoPaymentAmountTax",
        "promo_payment_amount_total": "PromoPaymentAmountTotal",
        "number_of_promo_autopays": "NumberOfPromoAutopays",
    }

    _optionals = [
        "id",
        "name",
        "description",
        "assigns_membership_id",
        "assigns_membership_name",
        "sold_online",
        "contract_items",
        "intro_offer",
        "autopay_schedule",
        "number_of_autopays",
        "autopay_trigger_type",
        "action_upon_completion_of_autopays",
        "clients_charged_on",
        "clients_charged_on_specific_date",
        "discount_amount",
        "deposit_amount",
        "first_autopay_free",
        "last_autopay_free",
        "client_terminate_online",
        "membership_type_restrictions",
        "location_purchase_restriction_ids",
        "location_purchase_restriction_names",
        "agreement_terms",
        "requires_electronic_confirmation",
        "autopay_enabled",
        "first_payment_amount_subtotal",
        "first_payment_amount_tax",
        "first_payment_amount_total",
        "recurring_payment_amount_subtotal",
        "recurring_payment_amount_tax",
        "recurring_payment_amount_total",
        "total_contract_amount_subtotal",
        "total_contract_amount_tax",
        "total_contract_amount_total",
        "promo_payment_amount_subtotal",
        "promo_payment_amount_tax",
        "promo_payment_amount_total",
        "number_of_promo_autopays",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        description=APIHelper.SKIP,
        assigns_membership_id=APIHelper.SKIP,
        assigns_membership_name=APIHelper.SKIP,
        sold_online=APIHelper.SKIP,
        contract_items=APIHelper.SKIP,
        intro_offer=APIHelper.SKIP,
        autopay_schedule=APIHelper.SKIP,
        number_of_autopays=APIHelper.SKIP,
        autopay_trigger_type=APIHelper.SKIP,
        action_upon_completion_of_autopays=APIHelper.SKIP,
        clients_charged_on=APIHelper.SKIP,
        clients_charged_on_specific_date=APIHelper.SKIP,
        discount_amount=APIHelper.SKIP,
        deposit_amount=APIHelper.SKIP,
        first_autopay_free=APIHelper.SKIP,
        last_autopay_free=APIHelper.SKIP,
        client_terminate_online=APIHelper.SKIP,
        membership_type_restrictions=APIHelper.SKIP,
        location_purchase_restriction_ids=APIHelper.SKIP,
        location_purchase_restriction_names=APIHelper.SKIP,
        agreement_terms=APIHelper.SKIP,
        requires_electronic_confirmation=APIHelper.SKIP,
        autopay_enabled=APIHelper.SKIP,
        first_payment_amount_subtotal=APIHelper.SKIP,
        first_payment_amount_tax=APIHelper.SKIP,
        first_payment_amount_total=APIHelper.SKIP,
        recurring_payment_amount_subtotal=APIHelper.SKIP,
        recurring_payment_amount_tax=APIHelper.SKIP,
        recurring_payment_amount_total=APIHelper.SKIP,
        total_contract_amount_subtotal=APIHelper.SKIP,
        total_contract_amount_tax=APIHelper.SKIP,
        total_contract_amount_total=APIHelper.SKIP,
        promo_payment_amount_subtotal=APIHelper.SKIP,
        promo_payment_amount_tax=APIHelper.SKIP,
        promo_payment_amount_total=APIHelper.SKIP,
        number_of_promo_autopays=APIHelper.SKIP):
        """Initialize a Contract instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if description is not APIHelper.SKIP:
            self.description = description
        if assigns_membership_id is not APIHelper.SKIP:
            self.assigns_membership_id = assigns_membership_id
        if assigns_membership_name is not APIHelper.SKIP:
            self.assigns_membership_name = assigns_membership_name
        if sold_online is not APIHelper.SKIP:
            self.sold_online = sold_online
        if contract_items is not APIHelper.SKIP:
            self.contract_items = contract_items
        if intro_offer is not APIHelper.SKIP:
            self.intro_offer = intro_offer
        if autopay_schedule is not APIHelper.SKIP:
            self.autopay_schedule = autopay_schedule
        if number_of_autopays is not APIHelper.SKIP:
            self.number_of_autopays = number_of_autopays
        if autopay_trigger_type is not APIHelper.SKIP:
            self.autopay_trigger_type = autopay_trigger_type
        if action_upon_completion_of_autopays is not APIHelper.SKIP:
            self.action_upon_completion_of_autopays =\
                 action_upon_completion_of_autopays
        if clients_charged_on is not APIHelper.SKIP:
            self.clients_charged_on = clients_charged_on
        if clients_charged_on_specific_date is not APIHelper.SKIP:
            self.clients_charged_on_specific_date =\
                 APIHelper.apply_datetime_converter(
                clients_charged_on_specific_date, APIHelper.RFC3339DateTime)\
                 if clients_charged_on_specific_date else None
        if discount_amount is not APIHelper.SKIP:
            self.discount_amount = discount_amount
        if deposit_amount is not APIHelper.SKIP:
            self.deposit_amount = deposit_amount
        if first_autopay_free is not APIHelper.SKIP:
            self.first_autopay_free = first_autopay_free
        if last_autopay_free is not APIHelper.SKIP:
            self.last_autopay_free = last_autopay_free
        if client_terminate_online is not APIHelper.SKIP:
            self.client_terminate_online = client_terminate_online
        if membership_type_restrictions is not APIHelper.SKIP:
            self.membership_type_restrictions = membership_type_restrictions
        if location_purchase_restriction_ids is not APIHelper.SKIP:
            self.location_purchase_restriction_ids =\
                 location_purchase_restriction_ids
        if location_purchase_restriction_names is not APIHelper.SKIP:
            self.location_purchase_restriction_names =\
                 location_purchase_restriction_names
        if agreement_terms is not APIHelper.SKIP:
            self.agreement_terms = agreement_terms
        if requires_electronic_confirmation is not APIHelper.SKIP:
            self.requires_electronic_confirmation = requires_electronic_confirmation
        if autopay_enabled is not APIHelper.SKIP:
            self.autopay_enabled = autopay_enabled
        if first_payment_amount_subtotal is not APIHelper.SKIP:
            self.first_payment_amount_subtotal = first_payment_amount_subtotal
        if first_payment_amount_tax is not APIHelper.SKIP:
            self.first_payment_amount_tax = first_payment_amount_tax
        if first_payment_amount_total is not APIHelper.SKIP:
            self.first_payment_amount_total = first_payment_amount_total
        if recurring_payment_amount_subtotal is not APIHelper.SKIP:
            self.recurring_payment_amount_subtotal =\
                 recurring_payment_amount_subtotal
        if recurring_payment_amount_tax is not APIHelper.SKIP:
            self.recurring_payment_amount_tax = recurring_payment_amount_tax
        if recurring_payment_amount_total is not APIHelper.SKIP:
            self.recurring_payment_amount_total = recurring_payment_amount_total
        if total_contract_amount_subtotal is not APIHelper.SKIP:
            self.total_contract_amount_subtotal = total_contract_amount_subtotal
        if total_contract_amount_tax is not APIHelper.SKIP:
            self.total_contract_amount_tax = total_contract_amount_tax
        if total_contract_amount_total is not APIHelper.SKIP:
            self.total_contract_amount_total = total_contract_amount_total
        if promo_payment_amount_subtotal is not APIHelper.SKIP:
            self.promo_payment_amount_subtotal = promo_payment_amount_subtotal
        if promo_payment_amount_tax is not APIHelper.SKIP:
            self.promo_payment_amount_tax = promo_payment_amount_tax
        if promo_payment_amount_total is not APIHelper.SKIP:
            self.promo_payment_amount_total = promo_payment_amount_total
        if number_of_promo_autopays is not APIHelper.SKIP:
            self.number_of_promo_autopays = number_of_promo_autopays

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        assigns_membership_id =\
            dictionary.get("AssignsMembershipId")\
            if dictionary.get("AssignsMembershipId")\
                else APIHelper.SKIP
        assigns_membership_name =\
            dictionary.get("AssignsMembershipName")\
            if dictionary.get("AssignsMembershipName")\
                else APIHelper.SKIP
        sold_online =\
            dictionary.get("SoldOnline")\
            if "SoldOnline" in dictionary.keys()\
                else APIHelper.SKIP
        contract_items = None
        if dictionary.get("ContractItems") is not None:
            contract_items = [
                ContractItem.from_dictionary(x)
                    for x in dictionary.get("ContractItems")
            ]
        else:
            contract_items = APIHelper.SKIP
        intro_offer =\
            dictionary.get("IntroOffer")\
            if dictionary.get("IntroOffer")\
                else APIHelper.SKIP
        autopay_schedule =\
            AutopaySchedule.from_dictionary(
                dictionary.get("AutopaySchedule"))\
                if "AutopaySchedule" in dictionary.keys()\
                else APIHelper.SKIP
        number_of_autopays =\
            dictionary.get("NumberOfAutopays")\
            if dictionary.get("NumberOfAutopays")\
                else APIHelper.SKIP
        autopay_trigger_type =\
            dictionary.get("AutopayTriggerType")\
            if dictionary.get("AutopayTriggerType")\
                else APIHelper.SKIP
        action_upon_completion_of_autopays =\
            dictionary.get("ActionUponCompletionOfAutopays")\
            if dictionary.get("ActionUponCompletionOfAutopays")\
                else APIHelper.SKIP
        clients_charged_on =\
            dictionary.get("ClientsChargedOn")\
            if dictionary.get("ClientsChargedOn")\
                else APIHelper.SKIP
        clients_charged_on_specific_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ClientsChargedOnSpecificDate")).datetime\
            if dictionary.get("ClientsChargedOnSpecificDate") else APIHelper.SKIP
        discount_amount =\
            dictionary.get("DiscountAmount")\
            if dictionary.get("DiscountAmount")\
                else APIHelper.SKIP
        deposit_amount =\
            dictionary.get("DepositAmount")\
            if dictionary.get("DepositAmount")\
                else APIHelper.SKIP
        first_autopay_free =\
            dictionary.get("FirstAutopayFree")\
            if "FirstAutopayFree" in dictionary.keys()\
                else APIHelper.SKIP
        last_autopay_free =\
            dictionary.get("LastAutopayFree")\
            if "LastAutopayFree" in dictionary.keys()\
                else APIHelper.SKIP
        client_terminate_online =\
            dictionary.get("ClientTerminateOnline")\
            if "ClientTerminateOnline" in dictionary.keys()\
                else APIHelper.SKIP
        membership_type_restrictions = None
        if dictionary.get("MembershipTypeRestrictions") is not None:
            membership_type_restrictions = [
                MembershipTypeRestriction.from_dictionary(x)
                    for x in dictionary.get("MembershipTypeRestrictions")
            ]
        else:
            membership_type_restrictions = APIHelper.SKIP
        location_purchase_restriction_ids =\
            dictionary.get("LocationPurchaseRestrictionIds")\
            if dictionary.get("LocationPurchaseRestrictionIds")\
                else APIHelper.SKIP
        location_purchase_restriction_names =\
            dictionary.get("LocationPurchaseRestrictionNames")\
            if dictionary.get("LocationPurchaseRestrictionNames")\
                else APIHelper.SKIP
        agreement_terms =\
            dictionary.get("AgreementTerms")\
            if dictionary.get("AgreementTerms")\
                else APIHelper.SKIP
        requires_electronic_confirmation =\
            dictionary.get("RequiresElectronicConfirmation")\
            if "RequiresElectronicConfirmation" in dictionary.keys()\
                else APIHelper.SKIP
        autopay_enabled =\
            dictionary.get("AutopayEnabled")\
            if "AutopayEnabled" in dictionary.keys()\
                else APIHelper.SKIP
        first_payment_amount_subtotal =\
            dictionary.get("FirstPaymentAmountSubtotal")\
            if dictionary.get("FirstPaymentAmountSubtotal")\
                else APIHelper.SKIP
        first_payment_amount_tax =\
            dictionary.get("FirstPaymentAmountTax")\
            if dictionary.get("FirstPaymentAmountTax")\
                else APIHelper.SKIP
        first_payment_amount_total =\
            dictionary.get("FirstPaymentAmountTotal")\
            if dictionary.get("FirstPaymentAmountTotal")\
                else APIHelper.SKIP
        recurring_payment_amount_subtotal =\
            dictionary.get("RecurringPaymentAmountSubtotal")\
            if dictionary.get("RecurringPaymentAmountSubtotal")\
                else APIHelper.SKIP
        recurring_payment_amount_tax =\
            dictionary.get("RecurringPaymentAmountTax")\
            if dictionary.get("RecurringPaymentAmountTax")\
                else APIHelper.SKIP
        recurring_payment_amount_total =\
            dictionary.get("RecurringPaymentAmountTotal")\
            if dictionary.get("RecurringPaymentAmountTotal")\
                else APIHelper.SKIP
        total_contract_amount_subtotal =\
            dictionary.get("TotalContractAmountSubtotal")\
            if dictionary.get("TotalContractAmountSubtotal")\
                else APIHelper.SKIP
        total_contract_amount_tax =\
            dictionary.get("TotalContractAmountTax")\
            if dictionary.get("TotalContractAmountTax")\
                else APIHelper.SKIP
        total_contract_amount_total =\
            dictionary.get("TotalContractAmountTotal")\
            if dictionary.get("TotalContractAmountTotal")\
                else APIHelper.SKIP
        promo_payment_amount_subtotal =\
            dictionary.get("PromoPaymentAmountSubtotal")\
            if dictionary.get("PromoPaymentAmountSubtotal")\
                else APIHelper.SKIP
        promo_payment_amount_tax =\
            dictionary.get("PromoPaymentAmountTax")\
            if dictionary.get("PromoPaymentAmountTax")\
                else APIHelper.SKIP
        promo_payment_amount_total =\
            dictionary.get("PromoPaymentAmountTotal")\
            if dictionary.get("PromoPaymentAmountTotal")\
                else APIHelper.SKIP
        number_of_promo_autopays =\
            dictionary.get("NumberOfPromoAutopays")\
            if dictionary.get("NumberOfPromoAutopays")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   description,
                   assigns_membership_id,
                   assigns_membership_name,
                   sold_online,
                   contract_items,
                   intro_offer,
                   autopay_schedule,
                   number_of_autopays,
                   autopay_trigger_type,
                   action_upon_completion_of_autopays,
                   clients_charged_on,
                   clients_charged_on_specific_date,
                   discount_amount,
                   deposit_amount,
                   first_autopay_free,
                   last_autopay_free,
                   client_terminate_online,
                   membership_type_restrictions,
                   location_purchase_restriction_ids,
                   location_purchase_restriction_names,
                   agreement_terms,
                   requires_electronic_confirmation,
                   autopay_enabled,
                   first_payment_amount_subtotal,
                   first_payment_amount_tax,
                   first_payment_amount_total,
                   recurring_payment_amount_subtotal,
                   recurring_payment_amount_tax,
                   recurring_payment_amount_total,
                   total_contract_amount_subtotal,
                   total_contract_amount_tax,
                   total_contract_amount_total,
                   promo_payment_amount_subtotal,
                   promo_payment_amount_tax,
                   promo_payment_amount_total,
                   number_of_promo_autopays)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _assigns_membership_id=(
            self.assigns_membership_id
            if hasattr(self, "assigns_membership_id")
            else None
        )
        _assigns_membership_name=(
            self.assigns_membership_name
            if hasattr(self, "assigns_membership_name")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _contract_items=(
            self.contract_items
            if hasattr(self, "contract_items")
            else None
        )
        _intro_offer=(
            self.intro_offer
            if hasattr(self, "intro_offer")
            else None
        )
        _autopay_schedule=(
            self.autopay_schedule
            if hasattr(self, "autopay_schedule")
            else None
        )
        _number_of_autopays=(
            self.number_of_autopays
            if hasattr(self, "number_of_autopays")
            else None
        )
        _autopay_trigger_type=(
            self.autopay_trigger_type
            if hasattr(self, "autopay_trigger_type")
            else None
        )
        _action_upon_completion_of_autopays=(
            self.action_upon_completion_of_autopays
            if hasattr(self, "action_upon_completion_of_autopays")
            else None
        )
        _clients_charged_on=(
            self.clients_charged_on
            if hasattr(self, "clients_charged_on")
            else None
        )
        _clients_charged_on_specific_date=(
            self.clients_charged_on_specific_date
            if hasattr(self, "clients_charged_on_specific_date")
            else None
        )
        _discount_amount=(
            self.discount_amount
            if hasattr(self, "discount_amount")
            else None
        )
        _deposit_amount=(
            self.deposit_amount
            if hasattr(self, "deposit_amount")
            else None
        )
        _first_autopay_free=(
            self.first_autopay_free
            if hasattr(self, "first_autopay_free")
            else None
        )
        _last_autopay_free=(
            self.last_autopay_free
            if hasattr(self, "last_autopay_free")
            else None
        )
        _client_terminate_online=(
            self.client_terminate_online
            if hasattr(self, "client_terminate_online")
            else None
        )
        _membership_type_restrictions=(
            self.membership_type_restrictions
            if hasattr(self, "membership_type_restrictions")
            else None
        )
        _location_purchase_restriction_ids=(
            self.location_purchase_restriction_ids
            if hasattr(self, "location_purchase_restriction_ids")
            else None
        )
        _location_purchase_restriction_names=(
            self.location_purchase_restriction_names
            if hasattr(self, "location_purchase_restriction_names")
            else None
        )
        _agreement_terms=(
            self.agreement_terms
            if hasattr(self, "agreement_terms")
            else None
        )
        _requires_electronic_confirmation=(
            self.requires_electronic_confirmation
            if hasattr(self, "requires_electronic_confirmation")
            else None
        )
        _autopay_enabled=(
            self.autopay_enabled
            if hasattr(self, "autopay_enabled")
            else None
        )
        _first_payment_amount_subtotal=(
            self.first_payment_amount_subtotal
            if hasattr(self, "first_payment_amount_subtotal")
            else None
        )
        _first_payment_amount_tax=(
            self.first_payment_amount_tax
            if hasattr(self, "first_payment_amount_tax")
            else None
        )
        _first_payment_amount_total=(
            self.first_payment_amount_total
            if hasattr(self, "first_payment_amount_total")
            else None
        )
        _recurring_payment_amount_subtotal=(
            self.recurring_payment_amount_subtotal
            if hasattr(self, "recurring_payment_amount_subtotal")
            else None
        )
        _recurring_payment_amount_tax=(
            self.recurring_payment_amount_tax
            if hasattr(self, "recurring_payment_amount_tax")
            else None
        )
        _recurring_payment_amount_total=(
            self.recurring_payment_amount_total
            if hasattr(self, "recurring_payment_amount_total")
            else None
        )
        _total_contract_amount_subtotal=(
            self.total_contract_amount_subtotal
            if hasattr(self, "total_contract_amount_subtotal")
            else None
        )
        _total_contract_amount_tax=(
            self.total_contract_amount_tax
            if hasattr(self, "total_contract_amount_tax")
            else None
        )
        _total_contract_amount_total=(
            self.total_contract_amount_total
            if hasattr(self, "total_contract_amount_total")
            else None
        )
        _promo_payment_amount_subtotal=(
            self.promo_payment_amount_subtotal
            if hasattr(self, "promo_payment_amount_subtotal")
            else None
        )
        _promo_payment_amount_tax=(
            self.promo_payment_amount_tax
            if hasattr(self, "promo_payment_amount_tax")
            else None
        )
        _promo_payment_amount_total=(
            self.promo_payment_amount_total
            if hasattr(self, "promo_payment_amount_total")
            else None
        )
        _number_of_promo_autopays=(
            self.number_of_promo_autopays
            if hasattr(self, "number_of_promo_autopays")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"description={_description!r}, "
            f"assigns_membership_id={_assigns_membership_id!r}, "
            f"assigns_membership_name={_assigns_membership_name!r}, "
            f"sold_online={_sold_online!r}, "
            f"contract_items={_contract_items!r}, "
            f"intro_offer={_intro_offer!r}, "
            f"autopay_schedule={_autopay_schedule!r}, "
            f"number_of_autopays={_number_of_autopays!r}, "
            f"autopay_trigger_type={_autopay_trigger_type!r}, "
            f"action_upon_completion_of_autopays={_action_upon_completion_of_autopays!r}, "
            f"clients_charged_on={_clients_charged_on!r}, "
            f"clients_charged_on_specific_date={_clients_charged_on_specific_date!r}, "
            f"discount_amount={_discount_amount!r}, "
            f"deposit_amount={_deposit_amount!r}, "
            f"first_autopay_free={_first_autopay_free!r}, "
            f"last_autopay_free={_last_autopay_free!r}, "
            f"client_terminate_online={_client_terminate_online!r}, "
            f"membership_type_restrictions={_membership_type_restrictions!r}, "
            f"location_purchase_restriction_ids={_location_purchase_restriction_ids!r}, "
            f"location_purchase_restriction_names={_location_purchase_restriction_names!r}, "
            f"agreement_terms={_agreement_terms!r}, "
            f"requires_electronic_confirmation={_requires_electronic_confirmation!r}, "
            f"autopay_enabled={_autopay_enabled!r}, "
            f"first_payment_amount_subtotal={_first_payment_amount_subtotal!r}, "
            f"first_payment_amount_tax={_first_payment_amount_tax!r}, "
            f"first_payment_amount_total={_first_payment_amount_total!r}, "
            f"recurring_payment_amount_subtotal={_recurring_payment_amount_subtotal!r}, "
            f"recurring_payment_amount_tax={_recurring_payment_amount_tax!r}, "
            f"recurring_payment_amount_total={_recurring_payment_amount_total!r}, "
            f"total_contract_amount_subtotal={_total_contract_amount_subtotal!r}, "
            f"total_contract_amount_tax={_total_contract_amount_tax!r}, "
            f"total_contract_amount_total={_total_contract_amount_total!r}, "
            f"promo_payment_amount_subtotal={_promo_payment_amount_subtotal!r}, "
            f"promo_payment_amount_tax={_promo_payment_amount_tax!r}, "
            f"promo_payment_amount_total={_promo_payment_amount_total!r}, "
            f"number_of_promo_autopays={_number_of_promo_autopays!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _assigns_membership_id=(
            self.assigns_membership_id
            if hasattr(self, "assigns_membership_id")
            else None
        )
        _assigns_membership_name=(
            self.assigns_membership_name
            if hasattr(self, "assigns_membership_name")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _contract_items=(
            self.contract_items
            if hasattr(self, "contract_items")
            else None
        )
        _intro_offer=(
            self.intro_offer
            if hasattr(self, "intro_offer")
            else None
        )
        _autopay_schedule=(
            self.autopay_schedule
            if hasattr(self, "autopay_schedule")
            else None
        )
        _number_of_autopays=(
            self.number_of_autopays
            if hasattr(self, "number_of_autopays")
            else None
        )
        _autopay_trigger_type=(
            self.autopay_trigger_type
            if hasattr(self, "autopay_trigger_type")
            else None
        )
        _action_upon_completion_of_autopays=(
            self.action_upon_completion_of_autopays
            if hasattr(self, "action_upon_completion_of_autopays")
            else None
        )
        _clients_charged_on=(
            self.clients_charged_on
            if hasattr(self, "clients_charged_on")
            else None
        )
        _clients_charged_on_specific_date=(
            self.clients_charged_on_specific_date
            if hasattr(self, "clients_charged_on_specific_date")
            else None
        )
        _discount_amount=(
            self.discount_amount
            if hasattr(self, "discount_amount")
            else None
        )
        _deposit_amount=(
            self.deposit_amount
            if hasattr(self, "deposit_amount")
            else None
        )
        _first_autopay_free=(
            self.first_autopay_free
            if hasattr(self, "first_autopay_free")
            else None
        )
        _last_autopay_free=(
            self.last_autopay_free
            if hasattr(self, "last_autopay_free")
            else None
        )
        _client_terminate_online=(
            self.client_terminate_online
            if hasattr(self, "client_terminate_online")
            else None
        )
        _membership_type_restrictions=(
            self.membership_type_restrictions
            if hasattr(self, "membership_type_restrictions")
            else None
        )
        _location_purchase_restriction_ids=(
            self.location_purchase_restriction_ids
            if hasattr(self, "location_purchase_restriction_ids")
            else None
        )
        _location_purchase_restriction_names=(
            self.location_purchase_restriction_names
            if hasattr(self, "location_purchase_restriction_names")
            else None
        )
        _agreement_terms=(
            self.agreement_terms
            if hasattr(self, "agreement_terms")
            else None
        )
        _requires_electronic_confirmation=(
            self.requires_electronic_confirmation
            if hasattr(self, "requires_electronic_confirmation")
            else None
        )
        _autopay_enabled=(
            self.autopay_enabled
            if hasattr(self, "autopay_enabled")
            else None
        )
        _first_payment_amount_subtotal=(
            self.first_payment_amount_subtotal
            if hasattr(self, "first_payment_amount_subtotal")
            else None
        )
        _first_payment_amount_tax=(
            self.first_payment_amount_tax
            if hasattr(self, "first_payment_amount_tax")
            else None
        )
        _first_payment_amount_total=(
            self.first_payment_amount_total
            if hasattr(self, "first_payment_amount_total")
            else None
        )
        _recurring_payment_amount_subtotal=(
            self.recurring_payment_amount_subtotal
            if hasattr(self, "recurring_payment_amount_subtotal")
            else None
        )
        _recurring_payment_amount_tax=(
            self.recurring_payment_amount_tax
            if hasattr(self, "recurring_payment_amount_tax")
            else None
        )
        _recurring_payment_amount_total=(
            self.recurring_payment_amount_total
            if hasattr(self, "recurring_payment_amount_total")
            else None
        )
        _total_contract_amount_subtotal=(
            self.total_contract_amount_subtotal
            if hasattr(self, "total_contract_amount_subtotal")
            else None
        )
        _total_contract_amount_tax=(
            self.total_contract_amount_tax
            if hasattr(self, "total_contract_amount_tax")
            else None
        )
        _total_contract_amount_total=(
            self.total_contract_amount_total
            if hasattr(self, "total_contract_amount_total")
            else None
        )
        _promo_payment_amount_subtotal=(
            self.promo_payment_amount_subtotal
            if hasattr(self, "promo_payment_amount_subtotal")
            else None
        )
        _promo_payment_amount_tax=(
            self.promo_payment_amount_tax
            if hasattr(self, "promo_payment_amount_tax")
            else None
        )
        _promo_payment_amount_total=(
            self.promo_payment_amount_total
            if hasattr(self, "promo_payment_amount_total")
            else None
        )
        _number_of_promo_autopays=(
            self.number_of_promo_autopays
            if hasattr(self, "number_of_promo_autopays")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"description={_description!s}, "
            f"assigns_membership_id={_assigns_membership_id!s}, "
            f"assigns_membership_name={_assigns_membership_name!s}, "
            f"sold_online={_sold_online!s}, "
            f"contract_items={_contract_items!s}, "
            f"intro_offer={_intro_offer!s}, "
            f"autopay_schedule={_autopay_schedule!s}, "
            f"number_of_autopays={_number_of_autopays!s}, "
            f"autopay_trigger_type={_autopay_trigger_type!s}, "
            f"action_upon_completion_of_autopays={_action_upon_completion_of_autopays!s}, "
            f"clients_charged_on={_clients_charged_on!s}, "
            f"clients_charged_on_specific_date={_clients_charged_on_specific_date!s}, "
            f"discount_amount={_discount_amount!s}, "
            f"deposit_amount={_deposit_amount!s}, "
            f"first_autopay_free={_first_autopay_free!s}, "
            f"last_autopay_free={_last_autopay_free!s}, "
            f"client_terminate_online={_client_terminate_online!s}, "
            f"membership_type_restrictions={_membership_type_restrictions!s}, "
            f"location_purchase_restriction_ids={_location_purchase_restriction_ids!s}, "
            f"location_purchase_restriction_names={_location_purchase_restriction_names!s}, "
            f"agreement_terms={_agreement_terms!s}, "
            f"requires_electronic_confirmation={_requires_electronic_confirmation!s}, "
            f"autopay_enabled={_autopay_enabled!s}, "
            f"first_payment_amount_subtotal={_first_payment_amount_subtotal!s}, "
            f"first_payment_amount_tax={_first_payment_amount_tax!s}, "
            f"first_payment_amount_total={_first_payment_amount_total!s}, "
            f"recurring_payment_amount_subtotal={_recurring_payment_amount_subtotal!s}, "
            f"recurring_payment_amount_tax={_recurring_payment_amount_tax!s}, "
            f"recurring_payment_amount_total={_recurring_payment_amount_total!s}, "
            f"total_contract_amount_subtotal={_total_contract_amount_subtotal!s}, "
            f"total_contract_amount_tax={_total_contract_amount_tax!s}, "
            f"total_contract_amount_total={_total_contract_amount_total!s}, "
            f"promo_payment_amount_subtotal={_promo_payment_amount_subtotal!s}, "
            f"promo_payment_amount_tax={_promo_payment_amount_tax!s}, "
            f"promo_payment_amount_total={_promo_payment_amount_total!s}, "
            f"number_of_promo_autopays={_number_of_promo_autopays!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateClientContractAutopaysRequest(object):
    """Implementation of the 'UpdateClientContractAutopaysRequest' model.

    Attributes:
        client_contract_id (int): Client Contract Id
        autopay_start_date (datetime): Autopay start date
        autopay_end_date (datetime): (optional) - Indefinite if not provided
        product_id (int): Product Id to update (optional if contract has only one
            product)
        replace_with_product_id (int): (optional) - Replaces the product with this
            product
        amount (float): Overrides autopay amount or amount that would come from
            ProductId
        overwrite_all_product_i_ds (bool): (optional) - If true, will update autopays
            with any productID

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_contract_id": "ClientContractId",
        "autopay_start_date": "AutopayStartDate",
        "autopay_end_date": "AutopayEndDate",
        "product_id": "ProductId",
        "replace_with_product_id": "ReplaceWithProductId",
        "amount": "Amount",
        "overwrite_all_product_i_ds": "OverwriteAllProductIDs",
    }

    _optionals = [
        "client_contract_id",
        "autopay_start_date",
        "autopay_end_date",
        "product_id",
        "replace_with_product_id",
        "amount",
        "overwrite_all_product_i_ds",
    ]

    def __init__(
        self,
        client_contract_id=APIHelper.SKIP,
        autopay_start_date=APIHelper.SKIP,
        autopay_end_date=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        replace_with_product_id=APIHelper.SKIP,
        amount=APIHelper.SKIP,
        overwrite_all_product_i_ds=APIHelper.SKIP):
        """Initialize a UpdateClientContractAutopaysRequest instance."""
        # Initialize members of the class
        if client_contract_id is not APIHelper.SKIP:
            self.client_contract_id = client_contract_id
        if autopay_start_date is not APIHelper.SKIP:
            self.autopay_start_date =\
                 APIHelper.apply_datetime_converter(
                autopay_start_date, APIHelper.RFC3339DateTime)\
                 if autopay_start_date else None
        if autopay_end_date is not APIHelper.SKIP:
            self.autopay_end_date =\
                 APIHelper.apply_datetime_converter(
                autopay_end_date, APIHelper.RFC3339DateTime)\
                 if autopay_end_date else None
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if replace_with_product_id is not APIHelper.SKIP:
            self.replace_with_product_id = replace_with_product_id
        if amount is not APIHelper.SKIP:
            self.amount = amount
        if overwrite_all_product_i_ds is not APIHelper.SKIP:
            self.overwrite_all_product_i_ds = overwrite_all_product_i_ds

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_contract_id =\
            dictionary.get("ClientContractId")\
            if dictionary.get("ClientContractId")\
                else APIHelper.SKIP
        autopay_start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("AutopayStartDate")).datetime\
            if dictionary.get("AutopayStartDate") else APIHelper.SKIP
        autopay_end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("AutopayEndDate")).datetime\
            if dictionary.get("AutopayEndDate") else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        replace_with_product_id =\
            dictionary.get("ReplaceWithProductId")\
            if dictionary.get("ReplaceWithProductId")\
                else APIHelper.SKIP
        amount =\
            dictionary.get("Amount")\
            if dictionary.get("Amount")\
                else APIHelper.SKIP
        overwrite_all_product_i_ds =\
            dictionary.get("OverwriteAllProductIDs")\
            if "OverwriteAllProductIDs" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_contract_id,
                   autopay_start_date,
                   autopay_end_date,
                   product_id,
                   replace_with_product_id,
                   amount,
                   overwrite_all_product_i_ds)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_contract_id=(
            self.client_contract_id
            if hasattr(self, "client_contract_id")
            else None
        )
        _autopay_start_date=(
            self.autopay_start_date
            if hasattr(self, "autopay_start_date")
            else None
        )
        _autopay_end_date=(
            self.autopay_end_date
            if hasattr(self, "autopay_end_date")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _replace_with_product_id=(
            self.replace_with_product_id
            if hasattr(self, "replace_with_product_id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        _overwrite_all_product_i_ds=(
            self.overwrite_all_product_i_ds
            if hasattr(self, "overwrite_all_product_i_ds")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_contract_id={_client_contract_id!r}, "
            f"autopay_start_date={_autopay_start_date!r}, "
            f"autopay_end_date={_autopay_end_date!r}, "
            f"product_id={_product_id!r}, "
            f"replace_with_product_id={_replace_with_product_id!r}, "
            f"amount={_amount!r}, "
            f"overwrite_all_product_i_ds={_overwrite_all_product_i_ds!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_contract_id=(
            self.client_contract_id
            if hasattr(self, "client_contract_id")
            else None
        )
        _autopay_start_date=(
            self.autopay_start_date
            if hasattr(self, "autopay_start_date")
            else None
        )
        _autopay_end_date=(
            self.autopay_end_date
            if hasattr(self, "autopay_end_date")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _replace_with_product_id=(
            self.replace_with_product_id
            if hasattr(self, "replace_with_product_id")
            else None
        )
        _amount=(
            self.amount
            if hasattr(self, "amount")
            else None
        )
        _overwrite_all_product_i_ds=(
            self.overwrite_all_product_i_ds
            if hasattr(self, "overwrite_all_product_i_ds")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_contract_id={_client_contract_id!s}, "
            f"autopay_start_date={_autopay_start_date!s}, "
            f"autopay_end_date={_autopay_end_date!s}, "
            f"product_id={_product_id!s}, "
            f"replace_with_product_id={_replace_with_product_id!s}, "
            f"amount={_amount!s}, "
            f"overwrite_all_product_i_ds={_overwrite_all_product_i_ds!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AutopaySchedule(object):
    """Implementation of the 'AutopaySchedule' model.

    Attributes:
        frequency_type (str): Defines how often clients are charged. Possible values
            are:  * SetNumberOfAutopays  * MonthToMonth
        frequency_value (int): The interval of AutoPay frequency, combined with
            `FrequencyTimeUnit`. This value is null if `FrequencyType` is
            `MonthToMonth`.
        frequency_time_unit (str): Defines the time unit that sets how often to run
            the AutoPay, combined with `FrequencyValue`. This value is null if
            `FrequencyType` is `MonthToMonth`. Possible values are:  * Weekly  *
            Monthly  * Yearly

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "frequency_type": "FrequencyType",
        "frequency_value": "FrequencyValue",
        "frequency_time_unit": "FrequencyTimeUnit",
    }

    _optionals = [
        "frequency_type",
        "frequency_value",
        "frequency_time_unit",
    ]

    def __init__(
        self,
        frequency_type=APIHelper.SKIP,
        frequency_value=APIHelper.SKIP,
        frequency_time_unit=APIHelper.SKIP):
        """Initialize a AutopaySchedule instance."""
        # Initialize members of the class
        if frequency_type is not APIHelper.SKIP:
            self.frequency_type = frequency_type
        if frequency_value is not APIHelper.SKIP:
            self.frequency_value = frequency_value
        if frequency_time_unit is not APIHelper.SKIP:
            self.frequency_time_unit = frequency_time_unit

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        frequency_type =\
            dictionary.get("FrequencyType")\
            if dictionary.get("FrequencyType")\
                else APIHelper.SKIP
        frequency_value =\
            dictionary.get("FrequencyValue")\
            if dictionary.get("FrequencyValue")\
                else APIHelper.SKIP
        frequency_time_unit =\
            dictionary.get("FrequencyTimeUnit")\
            if dictionary.get("FrequencyTimeUnit")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(frequency_type,
                   frequency_value,
                   frequency_time_unit)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _frequency_type=(
            self.frequency_type
            if hasattr(self, "frequency_type")
            else None
        )
        _frequency_value=(
            self.frequency_value
            if hasattr(self, "frequency_value")
            else None
        )
        _frequency_time_unit=(
            self.frequency_time_unit
            if hasattr(self, "frequency_time_unit")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"frequency_type={_frequency_type!r}, "
            f"frequency_value={_frequency_value!r}, "
            f"frequency_time_unit={_frequency_time_unit!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _frequency_type=(
            self.frequency_type
            if hasattr(self, "frequency_type")
            else None
        )
        _frequency_value=(
            self.frequency_value
            if hasattr(self, "frequency_value")
            else None
        )
        _frequency_time_unit=(
            self.frequency_time_unit
            if hasattr(self, "frequency_time_unit")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"frequency_type={_frequency_type!s}, "
            f"frequency_value={_frequency_value!s}, "
            f"frequency_time_unit={_frequency_time_unit!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class PricingRelationships(object):
    """Implementation of the 'PricingRelationships' model.

    Attributes:
        pays_for (List[int]): The model property of type List[int].
        paid_by (List[int]): The model property of type List[int].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "pays_for": "PaysFor",
        "paid_by": "PaidBy",
    }

    _optionals = [
        "pays_for",
        "paid_by",
    ]

    def __init__(
        self,
        pays_for=APIHelper.SKIP,
        paid_by=APIHelper.SKIP):
        """Initialize a PricingRelationships instance."""
        # Initialize members of the class
        if pays_for is not APIHelper.SKIP:
            self.pays_for = pays_for
        if paid_by is not APIHelper.SKIP:
            self.paid_by = paid_by

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        pays_for =\
            dictionary.get("PaysFor")\
            if dictionary.get("PaysFor")\
                else APIHelper.SKIP
        paid_by =\
            dictionary.get("PaidBy")\
            if dictionary.get("PaidBy")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(pays_for,
                   paid_by)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _pays_for=(
            self.pays_for
            if hasattr(self, "pays_for")
            else None
        )
        _paid_by=(
            self.paid_by
            if hasattr(self, "paid_by")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pays_for={_pays_for!r}, "
            f"paid_by={_paid_by!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _pays_for=(
            self.pays_for
            if hasattr(self, "pays_for")
            else None
        )
        _paid_by=(
            self.paid_by
            if hasattr(self, "paid_by")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pays_for={_pays_for!s}, "
            f"paid_by={_paid_by!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetContractsRequest(object):
    """Implementation of the 'GetContractsRequest' model.

    Request query information for GET sale/contracts endpoint

    Attributes:
        contract_ids (List[int]): When included, the response only contains details
            about the specified contract IDs.
        sold_online (bool): When `true`, the response only contains details about
            contracts and AutoPay options that can be sold online.   When `false`,
            all contracts are returned.  Default: **false**
        location_id (int): The ID of the location that has the requested contracts
            and AutoPay options.
        unique_client_id (int): The ID of the client.
        promo_code (str): PromoCode to apply
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "location_id": "LocationId",
        "contract_ids": "ContractIds",
        "sold_online": "SoldOnline",
        "unique_client_id": "UniqueClientId",
        "promo_code": "PromoCode",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "contract_ids",
        "sold_online",
        "unique_client_id",
        "promo_code",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        location_id=None,
        contract_ids=APIHelper.SKIP,
        sold_online=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        promo_code=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetContractsRequest instance."""
        # Initialize members of the class
        if contract_ids is not APIHelper.SKIP:
            self.contract_ids = contract_ids
        if sold_online is not APIHelper.SKIP:
            self.sold_online = sold_online
        self.location_id = location_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if promo_code is not APIHelper.SKIP:
            self.promo_code = promo_code
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else None
        contract_ids =\
            dictionary.get("ContractIds")\
            if dictionary.get("ContractIds")\
                else APIHelper.SKIP
        sold_online =\
            dictionary.get("SoldOnline")\
            if "SoldOnline" in dictionary.keys()\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        promo_code =\
            dictionary.get("PromoCode")\
            if dictionary.get("PromoCode")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(location_id,
                   contract_ids,
                   sold_online,
                   unique_client_id,
                   promo_code,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _contract_ids=(
            self.contract_ids
            if hasattr(self, "contract_ids")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _location_id=self.location_id
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _promo_code=(
            self.promo_code
            if hasattr(self, "promo_code")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"contract_ids={_contract_ids!r}, "
            f"sold_online={_sold_online!r}, "
            f"location_id={_location_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"promo_code={_promo_code!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _contract_ids=(
            self.contract_ids
            if hasattr(self, "contract_ids")
            else None
        )
        _sold_online=(
            self.sold_online
            if hasattr(self, "sold_online")
            else None
        )
        _location_id=self.location_id
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _promo_code=(
            self.promo_code
            if hasattr(self, "promo_code")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"contract_ids={_contract_ids!s}, "
            f"sold_online={_sold_online!s}, "
            f"location_id={_location_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"promo_code={_promo_code!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UploadClientPhotoResponse(object):
    """Implementation of the 'UploadClientPhotoResponse' model.

    Attributes:
        client_id (str): The RSSID of the client for whom the photo was uploaded.
        photo_url (str): The URL of the uploaded photo.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "photo_url": "PhotoUrl",
    }

    _optionals = [
        "client_id",
        "photo_url",
    ]

    def __init__(
        self,
        client_id=APIHelper.SKIP,
        photo_url=APIHelper.SKIP):
        """Initialize a UploadClientPhotoResponse instance."""
        # Initialize members of the class
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if photo_url is not APIHelper.SKIP:
            self.photo_url = photo_url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        photo_url =\
            dictionary.get("PhotoUrl")\
            if dictionary.get("PhotoUrl")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   photo_url)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _photo_url=(
            self.photo_url
            if hasattr(self, "photo_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"photo_url={_photo_url!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _photo_url=(
            self.photo_url
            if hasattr(self, "photo_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"photo_url={_photo_url!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.amenity import (
    Amenity,
)


class Location(object):
    """Implementation of the 'Location' model.

    Attributes:
        additional_image_ur_ls (List[str]): A list of URLs of any images associated
            with this location.
        address (str): The first line of the location’s street address.
        address_2 (str): A second address line for the location’s street address, if
            needed.
        amenities (List[Amenity]): A list of strings representing amenities available
            at the location.
        business_description (str): The business description for the location, as
            configured by the business owner.
        city (str): The location’s city.
        description (str): A description of the location.
        has_classes (bool): When `true`, indicates that classes are held at this
            location.<br />  When `false`, Indicates that classes are not held at
            this location.
        id (int): The ID assigned to this location.
        latitude (float): The location’s latitude.
        longitude (float): The location’s longitude.
        name (str): The name of this location.
        phone (str): The location’s phone number.
        phone_extension (str): The location’s phone extension.
        postal_code (str): The location’s postal code.
        site_id (int): The ID number assigned to this location.
        state_prov_code (str): The location’s state or province code.
        tax_1 (float): A decimal representation of the location’s first tax rate. Tax
            properties are provided to apply all taxes to the purchase price that the
            purchase is subject to. Use as many tax properties as needed to represent
            all the taxes that apply in the location. Enter a decimal number that
            represents the appropriate tax rate. For example, for an 8% sales tax,
            enter 0.08.
        tax_2 (float): A decimal representation of the location’s second tax rate.
            See the example in the description of Tax1.
        tax_3 (float): A decimal representation of the location’s third tax rate. See
            the example in the description of Tax1.
        tax_4 (float): A decimal representation of the location’s fourth tax rate.
            See the example in the description of Tax1.
        tax_5 (float): A decimal representation of the location’s fifth tax rate. See
            the example in the description of Tax1.
        total_number_of_ratings (int): The number of reviews that clients have left
            for this location.
        average_rating (float): The average rating for the location, out of five
            stars.
        total_number_of_deals (int): The number of distinct introductory pricing
            options available for purchase at this location.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "additional_image_ur_ls": "AdditionalImageURLs",
        "address": "Address",
        "address_2": "Address2",
        "amenities": "Amenities",
        "business_description": "BusinessDescription",
        "city": "City",
        "description": "Description",
        "has_classes": "HasClasses",
        "id": "Id",
        "latitude": "Latitude",
        "longitude": "Longitude",
        "name": "Name",
        "phone": "Phone",
        "phone_extension": "PhoneExtension",
        "postal_code": "PostalCode",
        "site_id": "SiteID",
        "state_prov_code": "StateProvCode",
        "tax_1": "Tax1",
        "tax_2": "Tax2",
        "tax_3": "Tax3",
        "tax_4": "Tax4",
        "tax_5": "Tax5",
        "total_number_of_ratings": "TotalNumberOfRatings",
        "average_rating": "AverageRating",
        "total_number_of_deals": "TotalNumberOfDeals",
    }

    _optionals = [
        "additional_image_ur_ls",
        "address",
        "address_2",
        "amenities",
        "business_description",
        "city",
        "description",
        "has_classes",
        "id",
        "latitude",
        "longitude",
        "name",
        "phone",
        "phone_extension",
        "postal_code",
        "site_id",
        "state_prov_code",
        "tax_1",
        "tax_2",
        "tax_3",
        "tax_4",
        "tax_5",
        "total_number_of_ratings",
        "average_rating",
        "total_number_of_deals",
    ]

    def __init__(
        self,
        additional_image_ur_ls=APIHelper.SKIP,
        address=APIHelper.SKIP,
        address_2=APIHelper.SKIP,
        amenities=APIHelper.SKIP,
        business_description=APIHelper.SKIP,
        city=APIHelper.SKIP,
        description=APIHelper.SKIP,
        has_classes=APIHelper.SKIP,
        id=APIHelper.SKIP,
        latitude=APIHelper.SKIP,
        longitude=APIHelper.SKIP,
        name=APIHelper.SKIP,
        phone=APIHelper.SKIP,
        phone_extension=APIHelper.SKIP,
        postal_code=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        state_prov_code=APIHelper.SKIP,
        tax_1=APIHelper.SKIP,
        tax_2=APIHelper.SKIP,
        tax_3=APIHelper.SKIP,
        tax_4=APIHelper.SKIP,
        tax_5=APIHelper.SKIP,
        total_number_of_ratings=APIHelper.SKIP,
        average_rating=APIHelper.SKIP,
        total_number_of_deals=APIHelper.SKIP):
        """Initialize a Location instance."""
        # Initialize members of the class
        if additional_image_ur_ls is not APIHelper.SKIP:
            self.additional_image_ur_ls = additional_image_ur_ls
        if address is not APIHelper.SKIP:
            self.address = address
        if address_2 is not APIHelper.SKIP:
            self.address_2 = address_2
        if amenities is not APIHelper.SKIP:
            self.amenities = amenities
        if business_description is not APIHelper.SKIP:
            self.business_description = business_description
        if city is not APIHelper.SKIP:
            self.city = city
        if description is not APIHelper.SKIP:
            self.description = description
        if has_classes is not APIHelper.SKIP:
            self.has_classes = has_classes
        if id is not APIHelper.SKIP:
            self.id = id
        if latitude is not APIHelper.SKIP:
            self.latitude = latitude
        if longitude is not APIHelper.SKIP:
            self.longitude = longitude
        if name is not APIHelper.SKIP:
            self.name = name
        if phone is not APIHelper.SKIP:
            self.phone = phone
        if phone_extension is not APIHelper.SKIP:
            self.phone_extension = phone_extension
        if postal_code is not APIHelper.SKIP:
            self.postal_code = postal_code
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if state_prov_code is not APIHelper.SKIP:
            self.state_prov_code = state_prov_code
        if tax_1 is not APIHelper.SKIP:
            self.tax_1 = tax_1
        if tax_2 is not APIHelper.SKIP:
            self.tax_2 = tax_2
        if tax_3 is not APIHelper.SKIP:
            self.tax_3 = tax_3
        if tax_4 is not APIHelper.SKIP:
            self.tax_4 = tax_4
        if tax_5 is not APIHelper.SKIP:
            self.tax_5 = tax_5
        if total_number_of_ratings is not APIHelper.SKIP:
            self.total_number_of_ratings = total_number_of_ratings
        if average_rating is not APIHelper.SKIP:
            self.average_rating = average_rating
        if total_number_of_deals is not APIHelper.SKIP:
            self.total_number_of_deals = total_number_of_deals

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        additional_image_ur_ls =\
            dictionary.get("AdditionalImageURLs")\
            if dictionary.get("AdditionalImageURLs")\
                else APIHelper.SKIP
        address =\
            dictionary.get("Address")\
            if dictionary.get("Address")\
                else APIHelper.SKIP
        address_2 =\
            dictionary.get("Address2")\
            if dictionary.get("Address2")\
                else APIHelper.SKIP
        amenities = None
        if dictionary.get("Amenities") is not None:
            amenities = [
                Amenity.from_dictionary(x)
                    for x in dictionary.get("Amenities")
            ]
        else:
            amenities = APIHelper.SKIP
        business_description =\
            dictionary.get("BusinessDescription")\
            if dictionary.get("BusinessDescription")\
                else APIHelper.SKIP
        city =\
            dictionary.get("City")\
            if dictionary.get("City")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        has_classes =\
            dictionary.get("HasClasses")\
            if "HasClasses" in dictionary.keys()\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        latitude =\
            dictionary.get("Latitude")\
            if dictionary.get("Latitude")\
                else APIHelper.SKIP
        longitude =\
            dictionary.get("Longitude")\
            if dictionary.get("Longitude")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        phone =\
            dictionary.get("Phone")\
            if dictionary.get("Phone")\
                else APIHelper.SKIP
        phone_extension =\
            dictionary.get("PhoneExtension")\
            if dictionary.get("PhoneExtension")\
                else APIHelper.SKIP
        postal_code =\
            dictionary.get("PostalCode")\
            if dictionary.get("PostalCode")\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteID")\
            if dictionary.get("SiteID")\
                else APIHelper.SKIP
        state_prov_code =\
            dictionary.get("StateProvCode")\
            if dictionary.get("StateProvCode")\
                else APIHelper.SKIP
        tax_1 =\
            dictionary.get("Tax1")\
            if dictionary.get("Tax1")\
                else APIHelper.SKIP
        tax_2 =\
            dictionary.get("Tax2")\
            if dictionary.get("Tax2")\
                else APIHelper.SKIP
        tax_3 =\
            dictionary.get("Tax3")\
            if dictionary.get("Tax3")\
                else APIHelper.SKIP
        tax_4 =\
            dictionary.get("Tax4")\
            if dictionary.get("Tax4")\
                else APIHelper.SKIP
        tax_5 =\
            dictionary.get("Tax5")\
            if dictionary.get("Tax5")\
                else APIHelper.SKIP
        total_number_of_ratings =\
            dictionary.get("TotalNumberOfRatings")\
            if dictionary.get("TotalNumberOfRatings")\
                else APIHelper.SKIP
        average_rating =\
            dictionary.get("AverageRating")\
            if dictionary.get("AverageRating")\
                else APIHelper.SKIP
        total_number_of_deals =\
            dictionary.get("TotalNumberOfDeals")\
            if dictionary.get("TotalNumberOfDeals")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(additional_image_ur_ls,
                   address,
                   address_2,
                   amenities,
                   business_description,
                   city,
                   description,
                   has_classes,
                   id,
                   latitude,
                   longitude,
                   name,
                   phone,
                   phone_extension,
                   postal_code,
                   site_id,
                   state_prov_code,
                   tax_1,
                   tax_2,
                   tax_3,
                   tax_4,
                   tax_5,
                   total_number_of_ratings,
                   average_rating,
                   total_number_of_deals)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _additional_image_ur_ls=(
            self.additional_image_ur_ls
            if hasattr(self, "additional_image_ur_ls")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _amenities=(
            self.amenities
            if hasattr(self, "amenities")
            else None
        )
        _business_description=(
            self.business_description
            if hasattr(self, "business_description")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _has_classes=(
            self.has_classes
            if hasattr(self, "has_classes")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _latitude=(
            self.latitude
            if hasattr(self, "latitude")
            else None
        )
        _longitude=(
            self.longitude
            if hasattr(self, "longitude")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _phone=(
            self.phone
            if hasattr(self, "phone")
            else None
        )
        _phone_extension=(
            self.phone_extension
            if hasattr(self, "phone_extension")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _state_prov_code=(
            self.state_prov_code
            if hasattr(self, "state_prov_code")
            else None
        )
        _tax_1=(
            self.tax_1
            if hasattr(self, "tax_1")
            else None
        )
        _tax_2=(
            self.tax_2
            if hasattr(self, "tax_2")
            else None
        )
        _tax_3=(
            self.tax_3
            if hasattr(self, "tax_3")
            else None
        )
        _tax_4=(
            self.tax_4
            if hasattr(self, "tax_4")
            else None
        )
        _tax_5=(
            self.tax_5
            if hasattr(self, "tax_5")
            else None
        )
        _total_number_of_ratings=(
            self.total_number_of_ratings
            if hasattr(self, "total_number_of_ratings")
            else None
        )
        _average_rating=(
            self.average_rating
            if hasattr(self, "average_rating")
            else None
        )
        _total_number_of_deals=(
            self.total_number_of_deals
            if hasattr(self, "total_number_of_deals")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"additional_image_ur_ls={_additional_image_ur_ls!r}, "
            f"address={_address!r}, "
            f"address_2={_address_2!r}, "
            f"amenities={_amenities!r}, "
            f"business_description={_business_description!r}, "
            f"city={_city!r}, "
            f"description={_description!r}, "
            f"has_classes={_has_classes!r}, "
            f"id={_id!r}, "
            f"latitude={_latitude!r}, "
            f"longitude={_longitude!r}, "
            f"name={_name!r}, "
            f"phone={_phone!r}, "
            f"phone_extension={_phone_extension!r}, "
            f"postal_code={_postal_code!r}, "
            f"site_id={_site_id!r}, "
            f"state_prov_code={_state_prov_code!r}, "
            f"tax_1={_tax_1!r}, "
            f"tax_2={_tax_2!r}, "
            f"tax_3={_tax_3!r}, "
            f"tax_4={_tax_4!r}, "
            f"tax_5={_tax_5!r}, "
            f"total_number_of_ratings={_total_number_of_ratings!r}, "
            f"average_rating={_average_rating!r}, "
            f"total_number_of_deals={_total_number_of_deals!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _additional_image_ur_ls=(
            self.additional_image_ur_ls
            if hasattr(self, "additional_image_ur_ls")
            else None
        )
        _address=(
            self.address
            if hasattr(self, "address")
            else None
        )
        _address_2=(
            self.address_2
            if hasattr(self, "address_2")
            else None
        )
        _amenities=(
            self.amenities
            if hasattr(self, "amenities")
            else None
        )
        _business_description=(
            self.business_description
            if hasattr(self, "business_description")
            else None
        )
        _city=(
            self.city
            if hasattr(self, "city")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _has_classes=(
            self.has_classes
            if hasattr(self, "has_classes")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _latitude=(
            self.latitude
            if hasattr(self, "latitude")
            else None
        )
        _longitude=(
            self.longitude
            if hasattr(self, "longitude")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _phone=(
            self.phone
            if hasattr(self, "phone")
            else None
        )
        _phone_extension=(
            self.phone_extension
            if hasattr(self, "phone_extension")
            else None
        )
        _postal_code=(
            self.postal_code
            if hasattr(self, "postal_code")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _state_prov_code=(
            self.state_prov_code
            if hasattr(self, "state_prov_code")
            else None
        )
        _tax_1=(
            self.tax_1
            if hasattr(self, "tax_1")
            else None
        )
        _tax_2=(
            self.tax_2
            if hasattr(self, "tax_2")
            else None
        )
        _tax_3=(
            self.tax_3
            if hasattr(self, "tax_3")
            else None
        )
        _tax_4=(
            self.tax_4
            if hasattr(self, "tax_4")
            else None
        )
        _tax_5=(
            self.tax_5
            if hasattr(self, "tax_5")
            else None
        )
        _total_number_of_ratings=(
            self.total_number_of_ratings
            if hasattr(self, "total_number_of_ratings")
            else None
        )
        _average_rating=(
            self.average_rating
            if hasattr(self, "average_rating")
            else None
        )
        _total_number_of_deals=(
            self.total_number_of_deals
            if hasattr(self, "total_number_of_deals")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"additional_image_ur_ls={_additional_image_ur_ls!s}, "
            f"address={_address!s}, "
            f"address_2={_address_2!s}, "
            f"amenities={_amenities!s}, "
            f"business_description={_business_description!s}, "
            f"city={_city!s}, "
            f"description={_description!s}, "
            f"has_classes={_has_classes!s}, "
            f"id={_id!s}, "
            f"latitude={_latitude!s}, "
            f"longitude={_longitude!s}, "
            f"name={_name!s}, "
            f"phone={_phone!s}, "
            f"phone_extension={_phone_extension!s}, "
            f"postal_code={_postal_code!s}, "
            f"site_id={_site_id!s}, "
            f"state_prov_code={_state_prov_code!s}, "
            f"tax_1={_tax_1!s}, "
            f"tax_2={_tax_2!s}, "
            f"tax_3={_tax_3!s}, "
            f"tax_4={_tax_4!s}, "
            f"tax_5={_tax_5!s}, "
            f"total_number_of_ratings={_total_number_of_ratings!s}, "
            f"average_rating={_average_rating!s}, "
            f"total_number_of_deals={_total_number_of_deals!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.payment_processing_failure import (
    PaymentProcessingFailure,
)


class PurchaseAccountCreditResponse(object):
    """Implementation of the 'PurchaseAccountCreditResponse' model.

    Attributes:
        amount_paid (float): The amount paid for the gift card by the purchaser.
        client_id (str): The client ID of the purchaser.
        sale_id (int): The sale ID of the gift card.
        email_receipt (bool): Whether or not an email receipt was sent to the
            purchaser. If true, a receipt was sent.
        payment_processing_failures (List[PaymentProcessingFailure]): Any cart
            processing failures, for example when SCA challenged, the cart is in
            PaymentAuthenticationRequired state and at least one of the failures
            listed will provide an authentication Url.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "amount_paid": "AmountPaid",
        "client_id": "ClientId",
        "sale_id": "SaleId",
        "email_receipt": "EmailReceipt",
        "payment_processing_failures": "PaymentProcessingFailures",
    }

    _optionals = [
        "amount_paid",
        "client_id",
        "sale_id",
        "email_receipt",
        "payment_processing_failures",
    ]

    def __init__(
        self,
        amount_paid=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        sale_id=APIHelper.SKIP,
        email_receipt=APIHelper.SKIP,
        payment_processing_failures=APIHelper.SKIP):
        """Initialize a PurchaseAccountCreditResponse instance."""
        # Initialize members of the class
        if amount_paid is not APIHelper.SKIP:
            self.amount_paid = amount_paid
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if email_receipt is not APIHelper.SKIP:
            self.email_receipt = email_receipt
        if payment_processing_failures is not APIHelper.SKIP:
            self.payment_processing_failures = payment_processing_failures

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        amount_paid =\
            dictionary.get("AmountPaid")\
            if dictionary.get("AmountPaid")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        email_receipt =\
            dictionary.get("EmailReceipt")\
            if "EmailReceipt" in dictionary.keys()\
                else APIHelper.SKIP
        payment_processing_failures = None
        if dictionary.get("PaymentProcessingFailures") is not None:
            payment_processing_failures = [
                PaymentProcessingFailure.from_dictionary(x)
                    for x in dictionary.get("PaymentProcessingFailures")
            ]
        else:
            payment_processing_failures = APIHelper.SKIP

        # Return an object of this model
        return cls(amount_paid,
                   client_id,
                   sale_id,
                   email_receipt,
                   payment_processing_failures)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _amount_paid=(
            self.amount_paid
            if hasattr(self, "amount_paid")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _email_receipt=(
            self.email_receipt
            if hasattr(self, "email_receipt")
            else None
        )
        _payment_processing_failures=(
            self.payment_processing_failures
            if hasattr(self, "payment_processing_failures")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"amount_paid={_amount_paid!r}, "
            f"client_id={_client_id!r}, "
            f"sale_id={_sale_id!r}, "
            f"email_receipt={_email_receipt!r}, "
            f"payment_processing_failures={_payment_processing_failures!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _amount_paid=(
            self.amount_paid
            if hasattr(self, "amount_paid")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _email_receipt=(
            self.email_receipt
            if hasattr(self, "email_receipt")
            else None
        )
        _payment_processing_failures=(
            self.payment_processing_failures
            if hasattr(self, "payment_processing_failures")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"amount_paid={_amount_paid!s}, "
            f"client_id={_client_id!s}, "
            f"sale_id={_sale_id!s}, "
            f"email_receipt={_email_receipt!s}, "
            f"payment_processing_failures={_payment_processing_failures!s}, "
            f")"
        )
